"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils_1 = require("../../../helpers/utils");
const uris = require("../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const fs = require('fs');
class Create extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.lbCreate = async (name, vpcName, certificate, privateKey, http, clientCertificate, verificationMode, crl, tlsv1, dynamicIps) => {
            var _a, _b;
            const orgId = this.session.selectedOrganization.id;
            try {
                (0, utils_1.validateCertificates)(certificate, privateKey, clientCertificate, crl);
                const vpc = await (0, utils_1.getVpcByName)(orgId, vpcName);
                const body = {
                    name: name,
                    state: 'STARTED',
                    httpMode: http || 'redirect',
                    defaultSslEndpoint: 0,
                    tlsv1: tlsv1 || false,
                    sslEndpoints: [{
                            publicKey: fs.readFileSync(certificate, 'utf-8'),
                            privateKey: fs.readFileSync(privateKey, 'utf-8'),
                            mappings: [{
                                    inputUri: '/{app}/',
                                    appName: '{app}',
                                    appUri: '/',
                                    upstreamProtocol: 'http',
                                }],
                        }],
                    staticIPsDisabled: dynamicIps || false,
                };
                if (clientCertificate) {
                    body.sslEndpoints[0].clientCert = fs.readFileSync(clientCertificate, 'utf-8');
                    body.sslEndpoints[0].verifyClientMode = verificationMode || 'optional';
                }
                if (crl) {
                    body.sslEndpoints[0].revocationList = fs.readFileSync(crl, 'utf-8');
                }
                const lb = await this.req.post(uris.loadBalancers(orgId, vpc.id), body);
                this.log('Created Load balancer', lb.data.name, 'with Common Name', lb.data.sslEndpoints[lb.data.defaultSslEndpoint].publicKeyCN);
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args, flags } = await this.parse(Create);
        await this.lbCreate(args.name, args.vpc, args.certificate, args.privateKey, flags.http, flags.clientCertificate, flags.verificationMode, flags.crl, flags.tlsv1, flags['dynamic-ips']);
    }
}
exports.default = Create;
Create.description = 'Create a Load balancer';
Create.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    http: core_1.Flags.string({ options: ['on', 'off', 'redirect'] }),
    clientCertificate: core_1.Flags.string(),
    verificationMode: core_1.Flags.string({ options: ['on', 'off', 'optional'] }),
    crl: core_1.Flags.string(),
    tlsv1: core_1.Flags.boolean(),
    'dynamic-ips': core_1.Flags.boolean(),
};
Create.args = [{ name: 'name' }, { name: 'vpc' }, { name: 'certificate' }, { name: 'privateKey' }];
