"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils_1 = require("../../../../helpers/utils");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const _ = require("lodash");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class Describe extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.lbMapsDescribe = async (args) => {
            var _a, _b;
            try {
                const lb = await (0, utils_1.getLoadBalancerByName)(this.session.selectedOrganization.id, args.name);
                const index = args.certificateName ?
                    _.findIndex(lb.sslEndpoints, { publicKeyCN: args.certificateName }) :
                    lb.defaultSslEndpoint;
                if (index === -1) {
                    return Promise.reject(new Error('No certificate named ' + args.certificateName + ' was found'));
                }
                const table = [];
                table.push(['Index', 'Input URI', 'App Name', 'App URI', 'Upstream Protocol']);
                _.each(lb.sslEndpoints[index].mappings, function (rule, idx) {
                    const data = [idx, rule.inputUri, rule.appName, rule.appUri, rule.upstreamProtocol];
                    table.push(data);
                });
                await this.show(table, lb.sslEndpoints[index].mappings);
            }
            catch (error) {
                ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args } = await this.parse(Describe);
        await this.lbMapsDescribe(args);
    }
}
exports.default = Describe;
Describe.description = 'Lists the proxy mapping rules for a Load balancer. ' +
    'If no certificateName is given, the mappings for the default SSL endpoint are shown';
Describe.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
Describe.args = [{ name: 'name', required: true },
    { name: 'certificateName' }];
