"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils_1 = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
class Remove extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.lbMapsRemove = async (args) => {
            var _a, _b;
            try {
                const { lb, index } = await (0, utils_1.findLoadBalancer)(this.session.selectedOrganization.id, args.name, args.certificateName);
                const url = uris.loadBalancer(this.session.selectedOrganization.id, lb.vpc.id, lb.id);
                const body = [{
                        op: 'remove',
                        path: `/sslEndpoints/${index}/mappings/${args.index}`,
                    }];
                const endpoint = (await this.req.patch(url, body)).data;
                this.log(`Mappings for Load balancer ${endpoint.name} updated successfully`);
            }
            catch (error) {
                ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args } = await this.parse(Remove);
        await this.lbMapsRemove(args);
    }
}
exports.default = Remove;
Remove.description = 'Remove a proxy mapping rule' +
    'If no certificateName is given, the mapping is removed from the default SSL endpoint';
Remove.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
};
Remove.args = [{ name: 'name', required: true },
    { name: 'certificateName', required: true },
    { name: 'index', required: true }];
