"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils_1 = require("../../../../helpers/utils");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const _ = require("lodash");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class Describe extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.lbSslEndpointDescribe = async (name, certificateName) => {
            var _a, _b;
            try {
                const lb = await (0, utils_1.getLoadBalancerByName)(this.session.selectedOrganization.id, name);
                const endpoint = _.find(lb.sslEndpoints, { publicKeyCN: certificateName });
                if (endpoint === undefined) {
                    this.error('An SSL endpoint with Common Name ' + certificateName + ' was not found');
                }
                const table = [];
                table.push(['Common Name', endpoint.publicKeyCN]);
                if (endpoint.publicKeySANs) {
                    table.push(['Subject Alternate Names', endpoint.publicKeySANs.join(', ')]);
                }
                if (endpoint.clientCertCN) {
                    table.push(['Client Certificate', endpoint.clientCertCN], ['Client verification', _.capitalize(endpoint.verifyClientMode)]);
                }
                if (endpoint.revocationListDigest) {
                    table.push(['Revocation list serial', endpoint.revocationListSerial], ['CRL last update', endpoint.revocationListLastUpdate], ['CRL next update', endpoint.revocationListNextUpdate]);
                }
                table.push(['Proxy mappings', endpoint.mappings.length]);
                await this.show(table, endpoint.mappings);
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args } = await this.parse(Describe);
        await this.lbSslEndpointDescribe(args.name, args.certificateName);
    }
}
exports.default = Describe;
Describe.description = 'Show the Load balancer configuration for a particular certificate';
Describe.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
Describe.args = [{ name: 'name', required: true },
    { name: 'certificateName', required: true }];
