"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const anypoint_cli_command_1 = require("anypoint-cli-command");
const cloudhubUris = require("../../../helpers/uris");
const core_1 = require("@oclif/core");
const utils_1 = require("../../../helpers/utils");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class Create extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.vpcCreate = async (args, flags, argv) => {
            var _a, _b;
            try {
                const environments = argv.slice(3, argv.length);
                const envs = await (0, utils_1.getResourcesByKey)(this, 'environments', 'id', 'name', environments);
                const url = cloudhubUris.vpcs(this.session.selectedOrganization.id);
                const body = {
                    name: args.name,
                    region: args.region,
                    cidrBlock: args.cidrBlock,
                    isDefault: flags.default || false,
                    associatedEnvironments: envs,
                    sharedWith: [],
                    internalDns: {},
                    firewallRules: [],
                    id: '',
                    ownerId: '',
                    vpcRoutes: undefined,
                };
                const vpcCreated = (await this.req.post(url, body)).data;
                const vpc = await (0, utils_1.showVpc)(vpcCreated, this);
                await this.show(vpc, JSON.stringify(vpc));
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { argv, args, flags } = await this.parse(Create);
        await this.vpcCreate(args, flags, argv);
    }
}
exports.default = Create;
Create.description = 'Create a new VPC';
Create.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    default: core_1.Flags.boolean({ description: 'Makes the VPC the default for the Organization.' }),
    ...flags_1.OutputFlag,
};
Create.strict = false;
Create.args = [{ name: 'name', required: true },
    { name: 'region', required: true },
    { name: 'cidrBlock', required: true },
    { name: 'environments' }];
