"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const uris_1 = require("../../../helpers/uris");
const flags_1 = require("../../../helpers/flags");
const flags_2 = require("anypoint-cli-command/lib/core/flags");
const utils_1 = require("../../../utils");
const util_1 = require("util");
const APPLICATION_JSON = 'application/json';
class Deploy extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args, flags } = await this.parse(Deploy);
        await this.cloudhubApplicationDeploy(args, flags);
    }
    async cloudhubApplicationDeploy(args, flags) {
        var _a, _b;
        try {
            const appData = (0, utils_1.handleCommonCreate)(args, flags, this.session.selectedOrganization.id);
            if (!appData.application.ref.version) {
                const app = await this.req.get((0, uris_1.exchangeGetAssetInfo)(this.session.selectedOrganization.id, appData.application.ref.artifactId, appData.application.ref.groupId));
                appData.application.ref.version = app.version;
                this.log((0, util_1.format)('Using latest exchange app (%s) version as default version: v%s', args.artifactId, app.version));
            }
            this.log('Deploying', args.name, '...');
            const url = (0, uris_1.cloudHub2Deployments)(this.session.selectedOrganization.id, this.session.selectedEnvironment.id);
            const displayApp = await this.req.post(url, appData, { headers: { 'Content-Type': APPLICATION_JSON } });
            (0, utils_1.showApplication)(this, displayApp.data);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = Deploy;
Deploy.description = 'Deploy a new application retrieved from exchange [artifactId] in target [deploymentTargetId] with runtime version [runtimeVersion]';
Deploy.args = [{ name: 'name', required: true },
    { name: 'deploymentTargetId', required: true },
    { name: 'runtimeVersion', required: true },
    { name: 'artifactId', required: true }];
Deploy.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.CommonCreateUpdateOptions2,
    ...flags_2.OutputFlag,
};
