"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const anypoint_cli_command_1 = require("anypoint-cli-command");
const uris_1 = require("../../../helpers/uris");
const moment = require("moment");
const util = require("util");
const _ = require("lodash");
class Logs extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.appLogs = async (args) => {
            var _a, _b;
            try {
                this.log('Tailing log... hit ctrl-c to stop tailing');
                const orgId = this.session.selectedOrganization.id;
                const envId = this.session.selectedEnvironment.id;
                await this.pullLatestLogs(this, orgId, envId, args, 0, 0);
            }
            catch (error) {
                const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
                this.error(errorMsg);
            }
        };
        this.pullLatestLogs = async (self, orgId, envId, args, latestTimestamp, docId) => {
            const uri = docId ? (0, uris_1.cloudHub2LogsAfterDocId)(orgId, envId, args.appId, args.specId, docId) : (0, uris_1.cloudHub2Logs)(orgId, envId, args.appId, args.specId);
            const { data: logTail } = await this.req.get(uri);
            if (logTail) {
                _.each(logTail, function (m) {
                    if (m.timestamp > latestTimestamp) {
                        const d = moment(m.timestamp);
                        self.log(util.format('"%s - [%s] %s - %s %s"', m.logLevel, d.format('HH:mm:ss D MMM'), m.context.logger, m.message, m.context.event));
                        latestTimestamp = m.timestamp;
                    }
                });
                const tail = _.last(logTail);
                latestTimestamp = tail.timestamp;
                const doc = _.last(logTail);
                docId = doc.docId;
                const fn = _.bind(this.pullLatestLogs, this, this, orgId, envId, args, latestTimestamp, docId);
                setTimeout(fn, 500);
            }
            else {
                self.log('no logs to tail');
            }
        };
    }
    async run() {
        const { args } = await this.parse(Logs);
        await this.appLogs(args);
    }
}
exports.default = Logs;
Logs.description = 'Tail application logs';
Logs.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
};
Logs.args = [{ name: 'appId', required: true },
    { name: 'specId', required: true }];
