"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const flags_1 = require("../../../helpers/flags");
const flags_2 = require("anypoint-cli-command/lib/core/flags");
const uris_1 = require("../../../helpers/uris");
const utils_1 = require("../../../utils");
const APPLICATION_JSON = 'application/json';
class Modify extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args, flags } = await this.parse(Modify);
        await this.cloudhubApplicationModify(args, flags);
    }
    async cloudhubApplicationModify(args, flags) {
        var _a, _b;
        try {
            const appData = (0, utils_1.handleCommonUpdate)(args, flags, this.session.selectedOrganization.id);
            if (!(appData.application.ref && appData.application.ref.version) && flags.assetId) {
                const app = await this.req.get((0, uris_1.exchangeGetAssetInfo)(this.session.selectedOrganization.id, appData.application.ref.artifactId, appData.application.ref.groupId));
                appData.application.ref.version = app.version;
                this.log('Using latest exchange app version as default version: v' + app.version);
            }
            this.log('Modifying', args.appId, '...');
            const url = (0, uris_1.cloudHub2App)(this.session.selectedOrganization.id, this.session.selectedEnvironment.id, args.appId);
            const displayApp = await this.req.patch(url, appData, { headers: { 'Content-Type': APPLICATION_JSON } });
            (0, utils_1.showApplication)(this, displayApp.data);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = Modify;
Modify.description = 'Modify an existing cloudhub 2 application';
Modify.args = [{ name: 'appId', required: true }];
Modify.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.CommonCreateUpdateOptions2,
    ...flags_2.OutputFlag,
};
