"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const uris_1 = require("../../../helpers/uris");
const utils_1 = require("../../../helpers/utils");
const utils_2 = require("anypoint-cli-command/lib/utils");
const FormData = require('form-data');
const fs = require('fs-extra');
class CopyReplace extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args } = await this.parse(CopyReplace);
        await this.cloudhubApplicationCopyReplace(args.source, args.target);
    }
    async cloudhubApplicationCopyReplace(source, target) {
        var _a, _b;
        try {
            const data = {};
            const sourceSession = (0, utils_1.parseAppCreds)(source);
            const targetSession = (0, utils_1.parseAppCreds)(target);
            const [sourceEnv, targetEnv] = await Promise.all([
                (0, utils_2.getEnvironmentByName)(sourceSession.environment, sourceSession.organization),
                (0, utils_2.getEnvironmentByName)(targetSession.environment, targetSession.organization),
            ]);
            sourceSession.envId = sourceEnv;
            targetSession.envId = targetEnv;
            this.log('Loading source application');
            const [sourceApp, targetApp] = await Promise.all([
                (0, utils_1.getSourceApp)(this, sourceSession),
                (0, utils_1.getSourceApp)(this, targetSession),
            ]);
            data.sourceApp = sourceApp.data;
            data.targetApp = targetApp.data;
            data.targetApp.fileName = data.sourceApp.fileName;
            this.log('Loading source application zip');
            const sourceZip = await (0, utils_1.downloadSourceZip)(this, sourceSession, data.sourceApp);
            data.zipPath = sourceZip;
            const appData = (0, utils_1.cleanAppData)(data.targetApp, targetSession);
            this.log('Copying source application to target');
            const fd = new FormData();
            fd.append('appInfoJson', JSON.stringify(appData));
            if (data.zipPath) {
                fd.append('file', fs.createReadStream(data.zipPath));
            }
            const { data: appAfter } = await this.req.put((0, uris_1.cloudAppV2)(appData.domain), fd, { headers: {
                    ...fd.getHeaders(),
                    'x-from-service': 'anypoint-cli',
                    'x-from-service-version': 'v2',
                    'target-info': 'target-info',
                    'X-ANYPNT-ENV-ID': targetSession.envId.id,
                    'X-ANYPNT-ORG-ID': targetSession.organization
                },
            });
            this.log(`Updating application ${appAfter.domain}`);
            if (fs.existsSync(data.zipPath)) {
                fs.remove(data.zipPath);
            }
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = CopyReplace;
CopyReplace.description = 'Copy cloud app from source to target, overwriting existing app and settings. "source" and "target" args format: [<org>[:<env>/]]<app>';
CopyReplace.args = [{ name: 'source', required: true },
    { name: 'target', required: true }];
CopyReplace.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
};
