"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const uris_1 = require("../../../helpers/uris");
const _ = require("lodash");
const fs = require("fs");
const flags_1 = require("../../../helpers/flags");
const utils_1 = require("../../../helpers/utils");
const flags_2 = require("anypoint-cli-command/lib/core/flags");
const FormData = require('form-data');
class Deploy extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args, flags } = await this.parse(Deploy);
        await this.cloudhubApplicationDeploy(args, flags);
    }
    async cloudhubApplicationDeploy(args, flags) {
        var _a, _b;
        try {
            fs.readFileSync(args.zipfile);
            const appData = (0, utils_1.handleCommonCreateUpdate)(flags, {});
            appData.domain = args.name;
            if (!_.has(appData, 'workers.amount')) {
                _.set(appData, 'workers.amount', 1);
            }
            appData.monitoringEnabled = true;
            appData.monitoringAutoRestart = true;
            this.log(`Deploying ${args.name} ...`);
            const fd = new FormData();
            fd.append('file', fs.createReadStream(args.zipfile));
            fd.append('autoStart', 'true');
            fd.append('appInfoJson', JSON.stringify(appData));
            const { data: appAfter } = await this.req.post(uris_1.cloudAppsV2, fd, { headers: {
                    ...fd.getHeaders(),
                    'x-from-service': 'anypoint-cli',
                    'x-from-service-version': 'v2'
                },
            });
            const table = (0, utils_1.showApplication)(appAfter);
            this.show(table, appAfter);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = Deploy;
Deploy.description = 'Deploy a new application';
Deploy.args = [{ name: 'name', required: true },
    { name: 'zipfile', required: true }];
Deploy.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.CommonCreateUpdateOptions,
    ...flags_2.OutputFlag,
};
