"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const _ = require("lodash");
const uris_1 = require("../../../helpers/uris");
const moment = require("moment");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class List extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        await this.cloudhubApplicationList();
    }
    async cloudhubApplicationList() {
        var _a, _b;
        try {
            const res = await this.req.get(uris_1.cloudAppsV2);
            const dataTable = res.data;
            const table = [];
            const header = ['Application', 'Status', 'vCores', 'Updated'];
            table.push(header);
            _.each(dataTable, function (app) {
                const data2 = [
                    `${app.domain} \n ${app.fileName}`,
                    getAppStatus(app),
                    `${app.workers.type.cpu} * ${app.workers.amount}`,
                    moment.utc(app.lastUpdateTime).fromNow(),
                ];
                table.push(data2);
            });
            await this.show(table, dataTable);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = List;
List.description = 'Lists all cloudhub applications in the environment';
List.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
function getAppStatus(app) {
    if (app.deploymentUpdateStatus === 'DEPLOY_FAILED' && app.status === 'STARTED') {
        return 'STARTED\n(Update failed)';
    }
    return app.deploymentUpdateStatus || app.status;
}
