"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const uris_1 = require("../../../helpers/uris");
const fs = require("fs");
const flags_1 = require("../../../helpers/flags");
const utils_1 = require("../../../helpers/utils");
const flags_2 = require("anypoint-cli-command/lib/core/flags");
const FormData = require('form-data');
class Modify extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args, flags } = await this.parse(Modify);
        await this.cloudhubApplicationModify(args, flags);
    }
    async cloudhubApplicationModify(args, flags) {
        var _a, _b;
        try {
            const { data: app } = await this.req.get((0, uris_1.cloudAppV2)(args.name));
            if (args.zipfile) {
                fs.readFileSync(args.zipfile);
            }
            const appData = (0, utils_1.handleCommonCreateUpdate)(flags, app);
            this.log('Updating ', args.name, '...');
            const fd = new FormData();
            fd.append('autoStart', 'true');
            fd.append('appInfoJson', JSON.stringify(appData));
            if (args.zipfile) {
                fd.append('file', fs.createReadStream(args.zipfile));
            }
            const { data: appAfter } = await this.req.put((0, uris_1.cloudAppV2)(args.name), fd, { headers: {
                    ...fd.getHeaders(),
                    'x-from-service': 'anypoint-cli',
                    'x-from-service-version': 'v2'
                },
            });
            const table = (0, utils_1.showApplication)(appAfter);
            await this.show(table, appAfter);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = Modify;
Modify.description = 'Modify an existing cloudhub application, optionally updating the zip file';
Modify.args = [{ name: 'name', required: true },
    { name: 'zipfile', required: false }];
Modify.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.CommonCreateUpdateOptions,
    ...flags_2.OutputFlag,
};
