"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const uris_1 = require("../../../helpers/uris");
const utils_1 = require("../../../helpers/utils");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
const FormData = require('form-data');
const _ = require('lodash');
class RevertRuntime extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args } = await this.parse(RevertRuntime);
        await this.cloudhubApplicationRevertRuntime(args.name);
    }
    async cloudhubApplicationRevertRuntime(name) {
        var _a, _b;
        try {
            const { data: app } = await this.req.get((0, uris_1.cloudAppV2)(name));
            if (!app.previousMuleVersion) {
                this.error('This application has no previous runtime to revert to');
            }
            const appData = {};
            _.set(appData, 'muleVersion.version', app.previousMuleVersion.version);
            const fd = new FormData();
            fd.append('appInfoJson', JSON.stringify(appData));
            const { data: appAfter } = await this.req.put((0, uris_1.cloudAppV2)(name), fd, { headers: {
                    ...fd.getHeaders(),
                    'x-from-service': 'anypoint-cli',
                    'x-from-service-version': 'v2'
                } });
            const table = (0, utils_1.showApplication)(appAfter);
            await this.show(table, appAfter);
        }
        catch (error) {
            const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
            this.error(errorMsg);
        }
    }
}
exports.default = RevertRuntime;
RevertRuntime.description = 'Restart a running cloudhub application';
RevertRuntime.args = [{ name: 'name', required: true }];
RevertRuntime.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
