"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const anypoint_cli_command_1 = require("anypoint-cli-command");
const uris_1 = require("../../../helpers/uris");
const moment = require("moment");
const util = require("util");
const _ = require("lodash");
class TailLogs extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.appTailLogs = async (name) => {
            var _a, _b;
            try {
                this.log('Tailing log... hit ctrl-c to stop tailing');
                const getData = (0, uris_1.cloudAppV2Deployments)(name);
                const { data: latestDeployment } = await this.req.get(getData.url, { params: getData.params });
                await this.pullLatestLogs(this, name, latestDeployment.data[0].deploymentId, 0);
            }
            catch (error) {
                const errorMsg = ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? error.response.data.message : error;
                this.error(errorMsg);
            }
        };
        this.pullLatestLogs = async (self, appName, deploymentId, latestTimestamp) => {
            const getData = (0, uris_1.cloudAppV2DeploymentLogs)(appName, deploymentId);
            const { data: logTail } = await this.req.get(getData.url, { params: getData.params });
            _.each(logTail.data, function (m) {
                if (m.timestamp > latestTimestamp) {
                    const d = moment(m.timestamp);
                    self.log(util.format('[%s] %s', d.format('HH:mm:ss D MMM'), m.message));
                    latestTimestamp = m.timestamp;
                }
            });
            const tail = _.last(logTail.data);
            latestTimestamp = tail.timestamp;
            const fn = _.bind(this.pullLatestLogs, this, this, appName, deploymentId, latestTimestamp);
            setTimeout(fn, 500);
        };
    }
    async run() {
        const { args } = await this.parse(TailLogs);
        await this.appTailLogs(args.name);
    }
}
exports.default = TailLogs;
TailLogs.description = 'Tail application logs';
TailLogs.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
};
TailLogs.args = [{ name: 'name', required: true }];
